"""Type tools for sound recognition"""


from atypes.util import MyType
from atypes.typ import *

from atypes.protocols import Gettable, Sliceable
